@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -35,6 +36,8 @@
 #include "grtdb/db_object_helpers.h"
 #include "grtsqlparser/mysql_parser_services.h"
 
+using namespace base;
+
 //--------------------------------------------------------------------------------------------------
 
 ExecuteRoutineWizard::ExecuteRoutineWizard(db_mysql_RoutineRef routine, const std::string &sql_mode) : Form(NULL) {
@@ -180,8 +183,14 @@ std::string ExecuteRoutineWizard::run() {
       return "";
   }
 
-  std::string schema_name = base::quote_identifier_if_needed(*_routine->owner()->name(), '`');
-  std::string routine_name = base::quote_identifier_if_needed(*_routine->name(), '`');
+  GrtVersionRef version;
+  if (_catalog.is_valid()) {
+    version = _catalog->version();
+  }
+  MySQLVersion versionEnum = bec::versionToEnum(version);
+
+  std::string schema_name = base::quoteIdentifierIfNeeded(*_routine->owner()->name(), '`', versionEnum);
+  std::string routine_name = base::quoteIdentifierIfNeeded(*_routine->name(), '`', versionEnum);
   if (base::tolower(_routine->routineType()) == "procedure") {
     std::string parameters_list;
     std::string variables_list;
@@ -208,7 +217,7 @@ std::string ExecuteRoutineWizard::run() {
         // Out or in/out parameter.
         // Since we cannot use DECLARE outside stored programs we use SET to define a variable
         // that can take the output of the call. Need to set a dummy value, however.
-        std::string parameter_name = base::quote_identifier_if_needed(*parameter->name(), '`');
+        std::string parameter_name = base::quoteIdentifierIfNeeded(*parameter->name(), '`', versionEnum);
         result += "set @" + parameter_name + " = ";
 
         std::string value = "0";
