@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2022, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -40,6 +41,11 @@ using namespace grt;
 
 DEFAULT_LOG_DOMAIN("SqlEditorSchemaTree");
 
+const short LiveSchemaTree::COLUMN_DATA = 0x01;
+const short LiveSchemaTree::TRIGGER_DATA = 0x02;
+const short LiveSchemaTree::INDEX_DATA = 0x04;
+const short LiveSchemaTree::FK_DATA = 0x08;
+
 const std::string LiveSchemaTree::SCHEMA_TAG = "_SCHEMA_";
 const std::string LiveSchemaTree::TABLES_TAG = "_TABLES_";
 const std::string LiveSchemaTree::VIEWS_TAG = "_VIEWS_";
@@ -422,15 +428,17 @@ std::string LiveSchemaTree::FunctionData::get_details(bool full, const mforms::T
 }
 //--------------------------------------------------------------------------------------------------
 
-LiveSchemaTree::LiveSchemaTree()
-  : _model_view(NULL),
+LiveSchemaTree::LiveSchemaTree(MySQLVersion version)
+  : _model_view(nullptr),
+    _schema_pattern(0),
+    _object_pattern(0),
     _case_sensitive_identifiers(false),
     _is_schema_contents_enabled(true),
     _enabled_events(false),
+    _version(version),
     _base(0),
-    _filter_type(Any),
-    _schema_pattern(0),
-    _object_pattern(0) {
+    _filter(),
+    _filter_type(Any) {
   fill_node_icons();
 
   // Setup the schema node collection skeleton
@@ -1795,7 +1803,14 @@ bool LiveSchemaTree::filter_children(ObjectType type, mforms::TreeNodeRef& sourc
   int count = source->count();
   for (int index = 0; index < count; index++) {
     mforms::TreeNodeRef source_node = source->get_child(index);
-    if (!validate || g_pattern_match_string(pattern, base::toupper(source_node->get_string(0)).c_str())) {
+
+// #ifdef GLIB_VERSION_2_70 won't work in RHEL9/OL9 because the glib-2.68 package already contains this definition
+#ifdef g_pattern_spec_match_string
+      bool match_string  = g_pattern_spec_match_string(pattern, base::toupper(source_node->get_string(0)).c_str());
+#else
+      bool match_string = g_pattern_match_string(pattern, base::toupper(source_node->get_string(0)).c_str());
+#endif
+    if (!validate || match_string) {
       std::vector<mforms::TreeNodeRef> group_added_nodes;
       _node_collections[type].captions.clear();
       _node_collections[type].captions.push_back(source_node->get_string(0));
@@ -2138,7 +2153,7 @@ void LiveSchemaTree::node_activated(mforms::TreeNodeRef node, int column) {
       }
       /* fall-thru */
       default:
-        node_name = base::quote_identifier_if_needed(node_name, '`');
+        node_name = base::quoteIdentifierIfNeeded(node_name, '`', _version);
         sql_editor_text_insert_signal(node_name);
         break;
     }
