@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -963,7 +964,7 @@ ColumnTypeCompareResult ColumnHelper::compare_column_types(const db_ColumnRef &f
 }
 
 void ColumnHelper::set_default_value(db_ColumnRef column, const std::string &value) {
-  column->defaultValueIsNull(base::string_compare(value, "NULL", false) ? 0 : 1);
+  column->defaultValueIsNull(base::same_string(value, "NULL", false) ? 1 : 0);
   column->defaultValue(value.c_str());
 
   // If a default value of NULL was set then the column can no longer be a not-null column.
