@@ -16,31 +16,30 @@
 /**
  * Extended text cell for vertically aligned text.
  */
-@interface VerticallyCenteredTextFieldCell : NSTextFieldCell
-{
+@interface VerticallyCenteredTextFieldCell : NSTextFieldCell {
 	BOOL mIsEditingOrSelecting;
 }
 
 @end
 
-@interface InfoBar : NSView <InfoBarCommunicator>
-{
+@interface InfoBar : NSView <InfoBarCommunicator> {
 @private
-  IBDisplay mDisplayMask;
+	NSImage *mBackground;
+	IBDisplay mDisplayMask;
 
-  float mScaleFactor;
-  NSPopUpButton* mZoomPopup;
+	float mScaleFactor;
+	NSPopUpButton *mZoomPopup;
 
-  int mCurrentCaretX;
-  int mCurrentCaretY;
-  NSTextField* mCaretPositionLabel;
-  NSTextField* mStatusTextLabel;
+	int mCurrentCaretX;
+	int mCurrentCaretY;
+	NSTextField *mCaretPositionLabel;
+	NSTextField *mStatusTextLabel;
 
-  id <InfoBarCommunicator> mCallback;
+	id <InfoBarCommunicator> mCallback;
 }
 
-- (void) notify: (NotificationType) type message: (NSString*) message location: (NSPoint) location
-          value: (float) value;
+- (void) notify: (NotificationType) type message: (NSString *) message location: (NSPoint) location
+	  value: (float) value;
 - (void) setCallback: (id <InfoBarCommunicator>) callback;
 
 - (void) createItems;
