@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2024, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -100,6 +101,14 @@ extern NSDictionary<NSString *, NSGradient *> *inactiveGradientsLight;
 
 @implementation WBRightClickThroughView
 
+// -(instancetype) initWithFrame: (NSRect)frame {
+//   self = [super initWithFrame: frame];
+//   if (self != nil) {
+//     self.clipsToBounds = YES;
+//   }
+//   return self;
+// }
+
 - (void)rightMouseDown: (NSEvent*)event {
   [self.superview rightMouseDown: event];
 }
@@ -124,13 +133,6 @@ extern NSDictionary<NSString *, NSGradient *> *inactiveGradientsLight;
 
 //----------------------------------------------------------------------------------------------------------------------
 
-- (void)drawRect: (NSRect)rect {
-  [[NSColor colorWithDeviceWhite: 232 / 255.0 alpha:1.0] set];
-  NSRectFill(rect);
-}
-
-//----------------------------------------------------------------------------------------------------------------------
-
 - (BOOL)isFlipped {
   return NO;
 }
@@ -514,8 +516,8 @@ extern NSDictionary<NSString *, NSGradient *> *inactiveGradientsLight;
             id oldTab = mSelectedTab;
             id newTab = item;
             mSelectedTab = newTab;
-            [oldTab setState: NSOffState];
-            [newTab setState: NSOnState];
+            [oldTab setState: NSControlStateValueOff];
+            [newTab setState: NSControlStateValueOn];
             mLastSelectedTabIndex = [mTabItems indexOfObject: newTab];
             [self layoutTabItemsDisregardingTabItem: nil];
 
@@ -828,7 +830,7 @@ extern NSDictionary<NSString *, NSGradient *> *inactiveGradientsLight;
     NSMenuItem* menuItem = [menu addItemWithTitle: item.label action: @selector(selectTabViewMenu:) keyEquivalent: @""];
     menuItem.target = self;
     menuItem.representedObject = item.identifier;
-    menuItem.state = ([mSelectedTab.identifier isEqual: item.identifier] ? NSOnState : NSOffState);
+    menuItem.state = ([mSelectedTab.identifier isEqual: item.identifier] ? NSControlStateValueOn : NSControlStateValueOff);
   }
 
   NSEvent* theEvent = NSApp.currentEvent;
