@@ -1,23 +1,28 @@
 /*
- * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
-#include "grtpp.h"
+#include "grt.h"
 #include "grtpp_util.h"
 
 #import "WBObjectDescriptionController.h"
@@ -26,9 +31,8 @@
 
 @implementation WBObjectDescriptionController
 
-- (void)setWBContext:(wb::WBContextUI*)be
+- (void)setup
 {
-  _wbui= be;
   [self updateForForm: 0];
 }
 
@@ -49,9 +53,9 @@
   std::string description;
 
   if (form)
-    description = _wbui->get_description_for_selection(form, new_object_list, items);
+    description = wb::WBContextUI::get()->get_description_for_selection(form, new_object_list, items);
   else
-    description = _wbui->get_description_for_selection(new_object_list, items);
+    description = wb::WBContextUI::get()->get_description_for_selection(new_object_list, items);
   
   // update only if selection was changed
   if (!_objectList || !grt::compare_list_contents(*_objectList, new_object_list))
@@ -83,7 +87,7 @@
         [text setEditable: YES];
         [forceEditButton setHidden:YES];
       }
-      [text setString: @(description.c_str())];
+      text.string = @(description.c_str());
     }
     else
     {
@@ -91,7 +95,7 @@
       [popup addItemWithTitle: @"No Selection"];
       [popup selectItemAtIndex: 0];
       
-      [text setString:@""];
+      text.string = @"";
       [text setEditable:NO];
       [forceEditButton setHidden:YES];
     }
@@ -120,13 +124,13 @@
   _timer= nil;
 
   if (_objectList)
-    _wbui->set_description_for_selection(*_objectList, [[text string] UTF8String]);
+    wb::WBContextUI::get()->set_description_for_selection(*_objectList, text.string.UTF8String);
 }
 
 
 - (void)textDidEndEditing:(NSNotification *)aNotification
 {
-  if ([text isEditable])
+  if (text.editable)
     [self commit];
 }
 
