@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2024, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -51,6 +52,7 @@ static NSString *stringFromNodeId(const bec::NodeId &node) {
     _be = owner.backend;
     _nodeId = new bec::NodeId(node);
     _tabItem = tabItem;
+    self.clipsToBounds = YES;
 
     [self setExpandSubviewsByDefault: NO];
     [self setBackgroundColor: NSColor.textBackgroundColor];
@@ -199,6 +201,7 @@ static NSString *stringFromNodeId(const bec::NodeId &node) {
 
   self = [super initWithFrame:NSMakeRect(0, 0, 100, 100)];
   if (self != nil) {
+    self.clipsToBounds = YES;
     self.tabViewType = NSTopTabsBezelBorder;
     
     [self doCustomize];
@@ -209,6 +212,7 @@ static NSString *stringFromNodeId(const bec::NodeId &node) {
     _nodeId= new bec::NodeId(node);
     
     _extraHeight= NSHeight(self.frame) - self.contentSize.height;
+    
   }
   return self;
 }
@@ -741,6 +745,7 @@ static NSDictionary *subtitleTextAttributes;
 - (instancetype)initWithOverview: (WBOverviewPanel*)owner nodeId: (const bec::NodeId&)node {
   self = [super initWithOverview: owner nodeId: node];
   if (self != nil) {
+    self.clipsToBounds = YES;
   }
   return self;
 }
