@@ -1,20 +1,25 @@
 /*
- * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- *  
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *  
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 using System;
@@ -120,7 +125,6 @@ namespace MySQL.GUI.Workbench
       statusStripImg.SizeMode = PictureBoxSizeMode.CenterImage;
       statusStripImg.Image = Resources.statusbar_output;
       statusStripImg.BackColor = Color.Transparent;
-      statusStripImg.Click += new System.EventHandler(grtOutputImg_Click);
       mainFormToolTip.SetToolTip(statusStripImg, "Display Output Window");
       host = new ToolStripControlHost(statusStripImg);
       host.Alignment = ToolStripItemAlignment.Right;
@@ -258,72 +262,6 @@ namespace MySQL.GUI.Workbench
       return false;
     }
 
-    private bool RequestInputPressedOk;
-
-    public void OnRequestInputButton(Object sender, EventArgs e)
-    {
-      Button b = sender as Button;
-      if (b == null)
-        return;
-      Form f = b.Parent as Form;
-      if (f == null)
-        return;
-      f.Close();
-      RequestInputPressedOk = (b.Text == "OK");
-    }
-
-    public bool RequestInput(String title, int flags, out String result)
-    {
-      this.RequestInputPressedOk = false;
-      result = "";
-
-      Form dialog = new Form();
-      if (flags != 0)
-        dialog.Text = "Input Password";
-      else
-        dialog.Text = "Input Text";
-      dialog.Size = new Size(350, 125);
-      dialog.StartPosition = FormStartPosition.CenterParent;
-      dialog.FormBorderStyle = FormBorderStyle.FixedDialog;
-
-      Label prompt = new Label();
-      prompt.Location = new Point(10, 5);
-      prompt.AutoSize = true;
-      prompt.Text = title;
-
-      TextBox input = new TextBox();
-      input.Location = new Point(10, 30);
-      input.Size = new Size(dialog.Size.Width - (input.Location.X * 2 + 1), 50);
-      if (flags != 0)
-        input.PasswordChar = '*';
-
-      Button ok = new Button();
-      ok.Text = "OK"; // if you rename this also update OnRequestInputButton()
-      ok.Location = new Point(dialog.Size.Width / 2 - ok.Size.Width - 10,
-        input.Location.Y + input.Size.Height + 10);
-      ok.Click += new EventHandler(OnRequestInputButton);
-
-      Button cancel = new Button();
-      cancel.Text = "Cancel";
-      cancel.Location = new Point(dialog.Size.Width / 2 + 10,
-        input.Location.Y + input.Size.Height + 10);
-      cancel.Click += new EventHandler(OnRequestInputButton);
-
-      dialog.AcceptButton = ok;
-      dialog.CancelButton = cancel;
-
-      dialog.Controls.Add(prompt);
-      dialog.Controls.Add(input);
-      dialog.Controls.Add(ok);
-      dialog.Controls.Add(cancel);
-      dialog.ShowDialog();
-
-      if (RequestInputPressedOk)
-        result = input.Text;
-
-      return RequestInputPressedOk;
-    }
-
     public String ApplicationCommand(AppCommand command, String str)
     {
       if (IsDisposed || Disposing)
@@ -364,7 +302,7 @@ namespace MySQL.GUI.Workbench
               workbenchPhysicalOverviewForm = null;
             }
 
-            wbContext.flush_idle_tasks();
+            wbContext.flush_idle_tasks(true);
             wbContext.close_document_finish();
 
             break;
@@ -1206,11 +1144,6 @@ namespace MySQL.GUI.Workbench
       return result;
     }
 
-    private void grtOutputImg_Click(object sender, EventArgs e)
-    {
-      wbContext.show_output();
-    }
-
     public void ShowPhysicalOverviewForm(bool isNew = false)
     {
       if (workbenchPhysicalOverviewForm == null)
@@ -1873,12 +1806,15 @@ namespace MySQL.GUI.Workbench
 
     private void tabsContextMenuItemClick(object sender, EventArgs e)
     {
-      TabPage page = contentTabControl.SelectedTab;
+      ToolStripMenuItem item = sender as ToolStripMenuItem;
+      int clickedTab = (int)item.Owner.Tag;
+
+      if (contentTabControl.TabCount < clickedTab || clickedTab < 0)
+        return;
+      TabPage page = contentTabControl.TabPages[clickedTab];
       if (page == null)
         return;
 
-      ToolStripMenuItem item = sender as ToolStripMenuItem;
-      int clickedTab = (int)item.Owner.Tag;
       switch (item.Tag as string)
       {
         case "0": // Close page.
@@ -1886,14 +1822,14 @@ namespace MySQL.GUI.Workbench
           break;
         case "1": // Close all editors but the clicked one.
           TabControl.TabPageCollection pages = contentTabControl.TabPages;
-          for (int i = 0; i < pages.Count; i++)
+          for (int i = 1; i < pages.Count; i++)
           {
-            // Do not close the home screen.
-            if (i == 0 || pages[i] == page)
+            if (pages[i] == page)
               continue;
-
             contentTabControl.CloseTabPage(pages[i]);
+            i = 0;
           }
+          contentTabControl.SelectedIndex = contentTabControl.TabPages.Count - 1;
           break;
         case "2": // Close tabs of the same type.
           ITabDocument document = contentTabControl.DocumentFromIndex(clickedTab);
