@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2024, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -48,6 +49,7 @@
   self = [super initWithFrame:aPanel.bounds];
   if (self) {
     panel = aPanel;
+    self.clipsToBounds = YES;
   }
   return self;
 }
@@ -239,6 +241,7 @@ STANDARD_MOUSE_HANDLING(panel) // Add handling for mouse events.
     mOwner = aPanel;
     mOwner->set_data(self);
     mType = type;
+    self.clipsToBounds = YES;
     switch (type) {
       case mforms::TransparentPanel: // just a container with no background
         [self setTransparent: YES];
