@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -25,6 +26,8 @@
 #import "MFMForms.h"
 #import "MFLabel.h"
 
+//----------------------------------------------------------------------------------------------------------------------
+
 struct CellEntry {
   NSView *view;
   bool isVisible;
@@ -39,6 +42,8 @@ struct CellEntry {
   bool verticalFill;
 };
 
+//----------------------------------------------------------------------------------------------------------------------
+
 @interface MFTableImpl ()  {
   float mRowSpacing;
   float mColumnSpacing;
@@ -54,6 +59,8 @@ struct CellEntry {
 
 @end
 
+//----------------------------------------------------------------------------------------------------------------------
+
 @implementation MFTableImpl
 
 - (instancetype)initWithObject:(::mforms::Table*)aTable
@@ -63,43 +70,52 @@ struct CellEntry {
   {
     mOwner = aTable;
     mOwner->set_data(self);
+    self.clipsToBounds = YES;
   }
   return self;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (mforms::Object*)mformsObject
 {
   return mOwner;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (BOOL)isFlipped
 {
   return YES;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void)setHomogeneous:(bool)flag
 {
   mHomogeneous= flag;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void)setRowSpacing:(float)spacing
 {
   mRowSpacing= spacing;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (void)setColumnSpacing:(float)spacing
 {
   mColumnSpacing= spacing;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 #if 0
 - (void)drawRect:(NSRect)rect
 {
@@ -148,7 +164,7 @@ static void applyBounds(std::vector<CellEntry> &list)
   }
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 /**
  * Computes the entire layout of the table. This includes size and position of client views.
@@ -495,7 +511,7 @@ static void applyBounds(std::vector<CellEntry> &list)
   return proposedSize;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (NSSize)preferredSize: (NSSize)proposedSize
 {
@@ -503,6 +519,8 @@ static void applyBounds(std::vector<CellEntry> &list)
   return [self computeLayout: proposedSize resizeChildren: NO];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (void)resizeSubviewsWithOldSize: (NSSize)oldBoundsSize
 {
   if (mOwner != nullptr && !mOwner->is_destroying())
@@ -548,17 +566,22 @@ static void applyBounds(std::vector<CellEntry> &list)
     [self relayout];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void)setRowCount:(int)count
 {
   mRowCount= count;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (void)setColumnCount:(int)count
 {
   mColumnCount= count;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 - (void)setPaddingLeft: (float)lpad right: (float)rpad top: (float)tpad bottom: (float)bpad
 {
   mLeftPadding = lpad;
@@ -570,11 +593,20 @@ static void applyBounds(std::vector<CellEntry> &list)
   mVerticalCenter = (tpad < 0 && bpad < 0);
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityTableRole;
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
 static bool table_create(::mforms::Table *self)
 {
   return [[MFTableImpl alloc] initWithObject: self] != nil;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void table_set_homogeneous(::mforms::Table *self, bool flag)
 {
@@ -589,6 +621,7 @@ static void table_set_homogeneous(::mforms::Table *self, bool flag)
   }
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void table_set_row_spacing(::mforms::Table *self, int spacing)
 {
@@ -603,6 +636,7 @@ static void table_set_row_spacing(::mforms::Table *self, int spacing)
   }
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void table_set_column_spacing(::mforms::Table *self, int spacing)
 {
@@ -617,6 +651,7 @@ static void table_set_column_spacing(::mforms::Table *self, int spacing)
   }
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void table_set_row_count(::mforms::Table *self, int count)
 {
@@ -631,6 +666,7 @@ static void table_set_row_count(::mforms::Table *self, int count)
   }
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void table_set_column_count(::mforms::Table *self, int count)
 {
@@ -645,6 +681,7 @@ static void table_set_column_count(::mforms::Table *self, int count)
   }
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void table_add(::mforms::Table *self, ::mforms::View *child, int left, int right, int top, int bottom, int flags)
 {
@@ -659,12 +696,14 @@ static void table_add(::mforms::Table *self, ::mforms::View *child, int left, in
                          flags: (mforms::TableItemFlags)flags];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 static void table_remove(::mforms::Table *self, ::mforms::View *child)
 {
   [child->get_data() removeFromSuperview];
 }
 
+//----------------------------------------------------------------------------------------------------------------------
 
 void cf_table_init()
 {
@@ -681,3 +720,5 @@ void cf_table_init()
 }
 
 @end
+
+//----------------------------------------------------------------------------------------------------------------------
