@@ -1,23 +1,31 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "mforms/mforms.h"
+#include "base/log.h"
+
+DEFAULT_LOG_DOMAIN(DOMAIN_MFORMS_BE)
 
 using namespace std;
 
@@ -40,7 +48,7 @@ static vector<BaseWidget*> animated_widgets;
 #define BK_RED 219 / 255.0
 #define BK_GREEN 217 / 255.0
 #define BK_BLUE 217 / 255.0
-#elif _WIN32
+#elif _MSC_VER
 #define WIDGET_FONT "Tahoma"
 #define WIDGET_SMALL_FONT "Arial"
 
@@ -108,7 +116,7 @@ static void stop_animation_timer_for(BaseWidget* widget) {
     }
 
   if (animation_timer_refcount <= 0)
-    g_warning("Unbalanced feedback timer deactivation in LineDiagramWidget.");
+    logWarning("Unbalanced feedback timer deactivation in LineDiagramWidget.");
   animation_timer_refcount--;
   if (animation_timer_refcount <= 0)
     ThreadedTimer::remove_task(animation_timer_id);
