@@ -1,16 +1,17 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -497,7 +498,7 @@ bool ViewWrapper::use_min_width_for_layout(Control ^ control) {
       (Panel::typeid ==
        control->GetType()) // Only the standard panel, not our derivation or we will cause an endless loop.
       || is<ComboBox>(control) || is<TreeViewAdv>(control) || is<ListBox>(control) || is<SplitContainer>(control) ||
-      is<System::Windows::Forms::WebBrowser>(control) || is<HtmlLabel>(control) || is<HtmlPanel>(control) ||
+      is<HtmlLabel>(control) || is<HtmlPanel>(control) ||
       is<ProgressBar>(control) || is<ScintillaControl>(control) || is<DataGridView>(control) || is<TextBox>(control);
   }
 
@@ -512,8 +513,7 @@ bool ViewWrapper::use_min_height_for_layout(Control ^ control) {
   if (!needsMinHeight) {
     needsMinHeight = is<TabControl>(control) || (Panel::typeid == control->GetType()) || is<ListBox>(control) ||
                      is<TreeViewAdv>(control) || is<SplitContainer>(control) ||
-                     is<System::Windows::Forms::WebBrowser>(control) || is<ScintillaControl>(control) ||
-                     is<DataGridView>(control);
+                     is<ScintillaControl>(control) || is<DataGridView>(control);
   }
 
   return needsMinHeight;
