@@ -5,12 +5,13 @@
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
+ * This program is designed to work with certain software (including
  * but not limited to OpenSSL) that is licensed under separate terms, as
  * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -1105,9 +1106,13 @@ void DiffSQLGeneratorBE::generate_routine_alter_stmt(db_mysql_RoutineRef old_rou
     if (_filtered_routines.find(routine_name_for_filter) == _filtered_routines.end())
       return;
 
-  generate_drop_stmt(old_routine);
-
-  generate_create_stmt(new_routine);
+  if (new_routine == old_routine) {
+    generate_drop_stmt(new_routine);
+    generate_create_stmt(new_routine, true);
+  } else {
+    generate_drop_stmt(old_routine);
+    generate_create_stmt(new_routine);
+  }
 }
 
 void DiffSQLGeneratorBE::generate_alter_stmt(db_mysql_SchemaRef schema, const grt::DiffChange *diffchange) {
@@ -1285,11 +1290,9 @@ void DiffSQLGeneratorBE::generate_alter_stmt(db_mysql_SchemaRef schema, const gr
               static_cast<const grt::ListItemRemovedChange *>(routine_change)->get_value()));
           } break;
           case grt::ListItemModified: {
-            db_mysql_RoutineRef old_routine = db_mysql_RoutineRef::cast_from(
-              grt::ValueRef(static_cast<const grt::ListItemModifiedChange *>(routine_change)->get_old_value()));
             db_mysql_RoutineRef new_routine = db_mysql_RoutineRef::cast_from(
               grt::ValueRef(static_cast<const grt::ListItemModifiedChange *>(routine_change)->get_new_value()));
-            generate_routine_alter_stmt(old_routine, new_routine, routine_change);
+            generate_routine_alter_stmt(new_routine, new_routine, routine_change);
           } break;
           case grt::ListItemOrderChanged:
             // list item position change is not relevant but may hold diff inside
