@@ -1,9 +1,9 @@
 layout = [ ( 'General',
     [ ( 'Features',
-        [ 'federated',
-          'enable-locking',
+        [ 'enable-locking',
           'enable-pstack',
           'event-scheduler',
+          'federated',
           'isam',
           'plugin',
           'plugin-load',
@@ -12,54 +12,82 @@ layout = [ ( 'General',
           'skip-partition']),
       ('Transactions', ['autocommit']),
       ( 'Memory usage',
-        [ 'host_cache_size',
-          'join_buffer_size',
+        [ 'join_buffer_size',
           'join_cache_level',
           'large-pages',
           'query_alloc_block_size',
           'sort_buffer_size']),
-      ('Informational', ['server-id', 'server-id-bits']),
+      ('Informational', ['server-id']),
       ('Directories', ['basedir', 'datadir', 'plugin_dir', 'tmpdir']),
       ( 'System',
-        [ 'core-file',
+        [ 'avoid_temporal_upgrade',
+          'core-file',
+          'disable-partition-engine-check',
+          'disabled_storage_engines',
           'external-locking',
           'gdb',
           'ignore-db-dir',
           'lower_case_table_names',
+          'mandatory_roles',
+          'no-monitor',
+          'offline_mode',
+          'partition',
+          'persisted_globals_load',
           'pid-file',
-          'skip-external-locking',
+          'server_id_bits',
+          'shared_memory',
+          'shared_memory_base_name',
           'skip-host-cache',
           'skip-locking',
+          'skip-safemalloc',
           'skip-stack-trace',
           'skip-symlink',
+          'skip_external_locking',
+          'super_read_only',
           'symbolic-links',
           'sysdate-is-now',
+          'tablespace_definition_cache',
+          'table_cache',
+          'table_lock_wait_timeout',
+          'tc-heuristic-recover',
+          'temp-pool',
+          'temptable_max_ram',
           'use-symbolic-links',
           'user',
-          'skip-safemalloc',
-          'lower_case_file_system',
-          'skip_external_locking']),
+          'version_tokens_session',
+          'version_tokens_session_number',
+          'windowing_use_high_precision']),
       ( 'General',
-        [ 'auto_increment_increment',
-          'auto_increment_offset',
-          'big-tables',
+        [ 'big-tables',
           'default-storage-engine',
-          'default_tmp_storage_engine',
           'default-table-type',
+          'default_tmp_storage_engine',
           'init-file',
           'lock_wait_timeout',
           'max_long_data_size',
-          'stored_program_cache',
+          'no-dd-upgrade',
           'old',
           'one-thread',
-          'super-large-pages',
-          'max_statement_time',
+          'session_track_gtids',
           'session_track_schema',
           'session_track_state_change',
-          'session_track_system_variables']),
+          'session_track_system_variables',
+          'show_compatibility_56',
+          'show_create_table_verbosity',
+          'show_old_temporals',
+          'stored_program_cache',
+          'stored_program_definition_cache',
+          'super-large-pages',
+          'verbose']),
+      ( 'Firewall',
+        [ 'mysql_firewall_max_query_size',
+          'mysql_firewall_mode',
+          'mysql_firewall_trace']),
       ( 'SQL',
         [ 'ansi',
+          'cte_max_recursion_depth',
           'explicit_defaults_for_timestamp',
+          'parser_max_mem_size',
           'sql-bin-update-same',
           'sql-mode']),
       ( 'International',
@@ -69,13 +97,13 @@ layout = [ ( 'General',
           'collation-server',
           'default-character-set',
           'default-collation',
+          'default_collation_for_utf8mb4',
           'default-time-zone',
           'default_week_format',
           'language',
           'lc-messages',
           'lc-messages-dir',
-          'skip-character-set-client-handshake',
-          'time_zone']),
+          'skip-character-set-client-handshake']),
       ( 'Backup',
         [ 'backup_elevation',
           'backup_history_log',
@@ -86,7 +114,21 @@ layout = [ ( 'General',
           'log-backup-output',
           'mysql-backup'])]),
   ( 'Logging',
-    [ ('Audit', ['audit-log']),
+    [ ( 'Audit',
+        [ 'audit-log',
+          'audit_log_buffer_size',
+          'audit_log_compression',
+          'audit_log_connection_policy',
+          'audit_log_encryption',
+          'audit_log_exclude_accounts',
+          'audit_log_file',
+          'audit_log_format',
+          'audit_log_include_accounts',
+          'audit_log_policy',
+          'audit_log_read_buffer_size',
+          'audit_log_rotate_on_size',
+          'audit_log_statement_policy',
+          'audit_log_strategy']),
       ( 'Slow query log options',
         [ 'log-slow-admin-statements',
           'log-slow-queries',
@@ -94,7 +136,8 @@ layout = [ ( 'General',
           'long_query_time',
           'slow_query_log_file']),
       ( 'Advanced log options',
-        [ 'expire_logs_days',
+        [ 'dragnet.log_error_filter_rules',
+          'expire_logs_days',
           'log-long-format',
           'log-tc',
           'log-tc-size',
@@ -110,35 +153,51 @@ layout = [ ( 'General',
           'log-queries-not-using-indexes',
           'log-raw',
           'log-short-format',
-          'log-slave-updates',
-          'slow-query-log',
+          'log_backward_compatible_user_definitions',
+          'log_builtin_as_identified_by_password',
+          'log_error_filter_rules',
+          'log_error_services',
           'log_error_verbosity',
           'log_slave_updates',
-          'log_timestamps']),
+          'log_syslog',
+          'log_syslog_facility',
+          'log_syslog_include_pid',
+          'log_syslog_tag',
+          'log_timestamps',
+          'slow-query-log']),
       ( 'Binlog Options',
         [ 'binlog-checksum',
           'binlog-do-db',
+          'binlog-format',
           'binlog-ignore-db',
           'binlog-row-event-max-size',
           'binlog_cache_size',
-          'binlog_stmt_cache_size',
-          'binlog-format',
-          'binlog-rows-query-log-events',
           'binlog_direct_non_transactional_updates',
+          'binlog_error_action',
+          'binlog_expire_logs_seconds',
+          'binlog_group_commit_sync_delay',
+          'binlog_group_commit_sync_no_delay_count',
+          'binlog_gtid_simple_recovery',
+          'binlog_row_image',
+          'binlog_row_metadata',
+          'binlog_row_value_options',
+          'binlog_rows_query_log_events',
+          'binlog_stmt_cache_size',
+          'binlog_transaction_dependency_tracking',
+          'binlog_transaction_dependency_history_size',
+          'binlogging_impossible_mode',
           'log-bin',
           'log-bin-index',
           'log-bin-trust-function-creators',
           'log-bin-trust-routine-creators',
-          'log-bin-use-v1-row-events',
           'log_bin_use_v1_row_events',
           'max-binlog-dump-events',
           'max_binlog_cache_size',
           'max_binlog_size',
           'max_binlog_stmt_cache_size',
+          'simplified_binlog_gtid_recovery',
           'sporadic-binlog-dump-fail',
-          'sync_binlog',
-          'binlog_impossible_mode',
-          'binlog_row_image'])]),
+          'sync_binlog'])]),
   ( 'InnoDB',
     [ ( 'Datafiles',
         [ 'innodb_data_file_path',
@@ -148,57 +207,73 @@ layout = [ ( 'General',
           'innodb_file_format_max']),
       ( 'Buffer pool',
         [ 'innodb_buffer_pool_awe_mem_mb',
+          'innodb_buffer_pool_chunk_size',
+          'innodb_buffer_pool_debug',
           'innodb_buffer_pool_dump_at_shutdown',
           'innodb_buffer_pool_dump_now',
           'innodb_buffer_pool_filename',
+          'innodb_buffer_pool_instances',
           'innodb_buffer_pool_load_abort',
           'innodb_buffer_pool_load_at_startup',
           'innodb_buffer_pool_load_now',
-          'innodb_buffer_pool_instances',
           'innodb_buffer_pool_size']),
       ( 'Logfiles',
-        [ 'innodb_flush_log_at_trx_commit',
+        [ 'innodb_ddl_log_crash_reset_debug',
+          'innodb_flush_log_at_trx_commit',
           'innodb_flush_method',
           'innodb_flush_neighbors',
+          'innodb_flush_sync',
           'innodb_log_arch_dir',
           'innodb_log_archive',
           'innodb_log_buffer_size',
+          'innodb_log_checksum_algorithm',
+          'innodb_log_checksums',
           'innodb_log_compressed_pages',
           'innodb_log_file_size',
           'innodb_log_files_in_group',
           'innodb_log_group_home_dir',
+          'innodb_log_spin_cpu_abs_lwm',
+          'innodb_log_spin_cpu_pct_hwm',
+          'innodb_log_wait_for_flush_spin_hwm',
+          'innodb_log_write_ahead_size',
           'innodb_mirrored_log_groups',
           'innodb_online_alter_log_max_size',
           'innodb_undo_directory',
-          'innodb_undo_logs',
-          'innodb_log_write_ahead_size']),
+          'innodb_undo_log_encrypt',
+          'innodb_undo_log_truncate',
+          'innodb_undo_logs']),
       ('Various', ['innodb_fast_shutdown']),
       ( 'Memory',
-        [ 'innodb_additional_mem_pool_size',
-          'innodb_buffer_pool_instances',
+        [ 'innodb_buffer_pool_instances',
           'innodb_buffer_pool_size',
+          'innodb_additional_mem_pool_size',
+          'innodb_page_cleaners',
           'innodb_page_size',
-          'innodb_sort_buffer_size',
-          'innodb_page_cleaners']),
+          'innodb_sort_buffer_size']),
       ( 'Fulltext search',
         [ 'innodb_ft_aux_table',
+          'innodb_ft_cache_size',
+          'innodb_ft_enable_diag_print',
           'innodb_ft_enable_stopword',
-          'innodb_ft_num_word_optimize',
-          'innodb_ft_server_stopword_table',
-          'innodb_ft_user_stopword_table',
           'innodb_ft_max_token_size',
           'innodb_ft_min_token_size',
-          'innodb_ft_cache_size',
-          'innodb_ft_sort_pll_degree',
-          'innodb_optimize_fulltext_only',
-          'innodb_ft_enable_diag_print',
+          'innodb_ft_num_word_optimize',
           'innodb_ft_result_cache_limit',
-          'innodb_ft_total_cache_size']),
+          'innodb_ft_server_stopword_table',
+          'innodb_ft_sort_pll_degree',
+          'innodb_ft_total_cache_size',
+          'innodb_ft_user_stopword_table',
+          'innodb_optimize_fulltext_only',
+          'mecab_rc_file',
+          'ngram_token_size']),
       ( 'General',
         [ 'ignore-builtin-innodb',
+          'innodb-safe-binlog',
+          'innodb-status-file',
           'innodb_adaptive_flushing',
           'innodb_adaptive_flushing_lwm',
           'innodb_adaptive_hash_index',
+          'innodb_adaptive_hash_index_parts',
           'innodb_adaptive_max_sleep_delay',
           'innodb_api_bk_commit_interval',
           'innodb_api_disable_rowlock',
@@ -207,26 +282,40 @@ layout = [ ( 'General',
           'innodb_api_trx_level',
           'innodb_autoextend_increment',
           'innodb_autoinc_lock_mode',
+          'innodb_background_drop_list_empty',
+          'innodb_buffer_pool_dump_pct',
           'innodb_change_buffer_max_size',
           'innodb_change_buffering',
+          'innodb_change_buffering_debug',
+          'innodb_checkpoint_disabled',
           'innodb_checksum_algorithm',
           'innodb_checksums',
           'innodb_cmp_per_index_enabled',
           'innodb_commit_concurrency',
+          'innodb_compress_debug',
           'innodb_compression_failure_threshold_pct',
           'innodb_compression_level',
           'innodb_compression_pad_pct_max',
           'innodb_concurrency_tickets',
+          'innodb_deadlock_detect',
+          'innodb_dedicated_server',
+          'innodb_default_row_format',
+          'innodb_directories',
+          'innodb_disable_sort_file_cache',
+          'innodb_disable_resize_buffer_pool_debug',
           'innodb_doublewrite',
           'innodb_extra_dirty_writes',
+          'innodb_fil_make_page_dirty_debug',
           'innodb_file_io_threads',
           'innodb_file_per_table',
+          'innodb_fill_factor',
           'innodb_flushing_avg_loops',
           'innodb_force_load_corrupted',
           'innodb_force_recovery',
           'innodb_io_capacity',
           'innodb_io_capacity_max',
           'innodb_large_prefix',
+          'innodb_limit_optimistic_insert_debug',
           'innodb_lock_wait_timeout',
           'innodb_locks_unsafe_for_binlog',
           'innodb_lru_scan_depth',
@@ -235,61 +324,74 @@ layout = [ ( 'General',
           'innodb_max_merged_io',
           'innodb_max_purge_lag',
           'innodb_max_purge_lag_delay',
+          'innodb_max_undo_log_size',
+          'innodb_merge_threshold_set_all_debug',
           'innodb_monitor_disable',
           'innodb_monitor_enable',
           'innodb_monitor_reset',
           'innodb_monitor_reset_all',
+          'innodb_numa_interleave',
           'innodb_old_blocks_pct',
           'innodb_old_blocks_time',
           'innodb_online_alter_log_max_size',
           'innodb_open_files',
+          'innodb_optimize_fulltext_only',
+          'innodb_optimize_point_storage',
           'innodb_print_all_deadlocks',
+          'innodb_print_ddl_logs',
           'innodb_purge_batch_size',
+          'innodb_purge_rseg_truncate_frequency',
           'innodb_purge_threads',
           'innodb_random_read_ahead',
           'innodb_read_ahead_threshold',
           'innodb_read_io_threads',
           'innodb_read_only',
+          'innodb_redo_log_encrypt',
           'innodb_replication_delay',
           'innodb_rollback_on_timeout',
           'innodb_rollback_segments',
-          'innodb-safe-binlog',
+          'innodb_saved_page_number_debug',
+          'innodb_scan_directories',
+          'innodb_sort_buffer_size',
+          'innodb_spin_wait_delay',
           'innodb_stats_auto_recalc',
+          'innodb_stats_include_delete_marked',
           'innodb_stats_method',
           'innodb_stats_on_metadata',
           'innodb_stats_persistent',
           'innodb_stats_persistent_sample_pages',
+          'innodb_stats_sample_pages',
           'innodb_stats_transient_sample_pages',
-          'innodb-status-file',
+          'innodb_status_output',
+          'innodb_status_output_locks',
+          'innodb_strict_mode',
           'innodb_support_xa',
           'innodb_sync_array_size',
           'innodb_sync_spin_loops',
-          'innodb_sort_buffer_size',
-          'innodb_spin_wait_delay',
-          'innodb_stats_sample_pages',
-          'innodb_strict_mode',
+          'innodb_sync_debug',
           'innodb_table_locks',
+          'innodb_temp_data_file_path',
+          'internal_tmp_mem_storage_engine',
+          'innodb_tmpdir',
           'innodb_thread_concurrency',
           'innodb_thread_concurrency_timer_based',
           'innodb_thread_sleep_delay',
+          'innodb_trx_purge_view_update_only_debug',
+          'innodb_trx_rseg_n_slots_debug',
           'innodb_undo_directory',
+          'innodb_undo_log_encrypt',
+          'innodb_undo_log_truncate',
           'innodb_undo_logs',
           'innodb_undo_tablespaces',
           'innodb_use_legacy_cardinality_algorithm',
           'innodb_use_native_aio',
           'innodb_use_sys_malloc',
           'innodb_write_io_threads',
+          'internal_tmp_disk_storage_engine',
           'timed_mutexes',
-          'innodb_optimize_fulltext_only',
-          'skip-innodb',
-          'innodb_buffer_pool_dump_pct',
-          'innodb_disable_sort_file_cache',
-          'innodb_status_output',
-          'innodb_status_output_locks',
-          'innodb_temp_data_file_path'])]),
+          'skip-innodb'])]),
   ( 'Networking',
-    [ ( 'Data / Memory size',
-        ['host_cache_size', 'max_allowed_packet', 'net_buffer_length']),
+    [ ('Data / Memory size', ['max_allowed_packet', 'net_buffer_length']),
       ( 'SSL',
         [ 'ssl',
           'ssl-ca',
@@ -298,8 +400,8 @@ layout = [ ( 'General',
           'ssl-cipher',
           'ssl-crl',
           'ssl-crlpath',
-          'ssl-key',
-          'ssl-verify-server-cert']),
+          'ssl_fips_mode',
+          'ssl-key']),
       ( 'Timeout Settings',
         [ 'connect_timeout',
           'interactive_timeout',
@@ -312,14 +414,13 @@ layout = [ ( 'General',
           'max_user_connections',
           'net_retry_count']),
       ( 'General',
-        [ 'back_log',
-          'bind-address',
+        [ 'bind-address',
+          'enable-named-pipe',
           'port',
           'port-open-timeout',
           'skip-name-resolve',
           'skip-networking',
-          'socket',
-          'enable-named-pipe'])]),
+          'socket'])]),
   ( 'Advanced',
     [ ( 'Transactions',
         [ 'completion_type',
@@ -328,27 +429,29 @@ layout = [ ( 'General',
           'transaction_alloc_block_size',
           'transaction_prealloc_size']),
       ( 'Deprecated',
-        ['old-protocol', 'old-alter-table', 'set-variable', 'warnings']),
+        ['old-alter-table', 'old-protocol', 'set-variable', 'warnings']),
       ( 'Thread specific settings',
         [ 'slow_launch_time',
           'thread_cache_size',
           'thread_concurrency',
           'thread_handling',
-          'thread_pool_size',
-          'thread_stack',
           'thread_pool_algorithm',
           'thread_pool_high_priority_connection',
           'thread_pool_max_unused_threads',
           'thread_pool_prio_kickup_timer',
-          'thread_pool_stall_limit']),
+          'thread_pool_size',
+          'thread_pool_stall_limit',
+          'thread_stack']),
       ( 'Various',
         [ 'bulk_insert_buffer_size',
           'group_concat_max_len',
           'key_cache_block_size',
           'key_cache_division_limit',
+          'max_execution_time',
           'max_heap_table_size',
           'max_join_size',
           'max_length_for_sort_data',
+          'max_points_in_geometry',
           'max_seeks_for_key',
           'max_sort_length',
           'max_write_lock_count',
@@ -358,8 +461,11 @@ layout = [ ( 'General',
           'query_alloc_block_size',
           'query_prealloc_size',
           'range_alloc_block_size',
+          'range_optimizer_max_mem_size',
           'read_buffer_size',
           'read_rnd_buffer_size',
+          'regexp_stack_limit',
+          'regexp_time_limit',
           'tmp_table_size']),
       ( 'Insert delayed settings',
         [ 'delayed_insert_limit',
@@ -369,14 +475,20 @@ layout = [ ( 'General',
       ( 'General',
         [ 'bootstrap',
           'chroot',
+          'daemonize',
+          'debug',
           'debug-sync-timeout',
           'div_precision_increment',
-          'eq_range_index_dive_limit',
+          'early-plugin-load',
           'exit-info',
           'flush',
           'flush_time',
+          'gtid-executed-compression-period',
           'init_connect',
           'init_slave',
+          'initialize',
+          'initialize-insecure',
+          'max_digest_length',
           'max_error_count',
           'max_prepared_stmt_count',
           'max_sp_recursion_depth',
@@ -391,109 +503,212 @@ layout = [ ( 'General',
           'skip-concurrent-insert',
           'skip-thread-priority',
           'slow-start-timeout',
+          'standalone',
           'sync_frm',
-          'updatable_views_with_limit',
-          'debug',
-          'standalone'])]),
+          'updatable_views_with_limit'])]),
   ( 'Other',
-    [ ( 'Storage Engines',
-        ['skip-bdb', 'skip-merge', 'skip-sync-bdb-logs', 'skip-falcon']),
+    [ ( 'X',
+        [ 'mysqlx-ssl',
+          'mysqlx-ssl-key',
+          'mysqlx-ssl-ca',
+          'mysqlx-ssl-capath',
+          'mysqlx-ssl-cert',
+          'mysqlx-ssl-cipher',
+          'mysqlx-ssl-crl',
+          'mysqlx-ssl-crlpath',
+          'mysqlx_bind_address',
+          'mysqlx_connect_timeout',
+          'mysqlx_document_id_unique_prefix',
+          'mysqlx_idle_worker_thread_timeout',
+          'mysqlx_interactive_timeout',
+          'mysqlx_max_allowed_packet',
+          'mysqlx_max_connections',
+          'mysqlx_min_worker_threads',
+          'mysqlx_port',
+          'mysqlx_port_open_timeout',
+          'mysqlx_read_timeout',
+          'mysqlx_socket',
+          'mysqlx_wait_timeout',
+          'mysqlx_write_timeout']),
       ( 'NDB',
-        [ 'ndb_autoincrement_prefetch_sz',
+        [ 'create_old_temporals',
           'ndb-batch-size',
           'ndb-blob-read-batch-bytes',
           'ndb-blob-write-batch-bytes',
-          'ndb_cache_check_time',
           'ndb-cluster-connection-pool',
+          'ndb-cluster-connection-pool-nodeids',
           'ndb-connectstring',
-          'ndb_extra_logging',
-          'ndb_force_send',
-          'ndb-log-apply-status',
           'ndb-log-transaction-id',
-          'ndb_log_updated_only',
           'ndb-log-update-as-write',
-          'ndb-log-empty-epochs',
-          'ndb_log_empty_epochs',
-          'ndb-nodeid',
           'ndb-mgmd-host',
-          'ndb-wait-connected',
-          'ndb-wait-setup',
-          'ndbcluster',
-          'ndb-deferred-constraints',
-          'ndb_deferred_constraints',
-          'ndb-distribution',
-          'ndb_distribution',
-          'ndb_index_stat_cache_entries',
-          'ndb_index_stat_enable',
-          'ndb_index_stat_update_freq',
-          'ndb_optimized_node_selection',
-          'ndb_report_thresh_binlog_epoch_slip',
-          'ndb_report_thresh_binlog_mem_usage',
-          'ndb_use_transactions',
-          'ndb-log-orig',
+          'ndb-nodeid',
           'ndb-recv-thread-activation-threshold',
           'ndb-recv-thread-cpu-mask',
-          'ndb_index_stat_option']),
+          'ndb-wait-connected',
+          'ndb-wait-setup',
+          'ndb-allow-copying-alter-table',
+          'ndb_autoincrement_prefetch_sz',
+          'ndb_cache_check_time',
+          'ndb_data_node_neighbour',
+          'ndb_default_column_format',
+          'ndb_deferred_constraints',
+          'ndb_distribution',
+          'ndb_eventbuffer_free_percent',
+          'ndb_eventbuffer_max_alloc',
+          'ndb_extra_logging',
+          'ndb_force_send',
+          'ndb_fully_replicated',
+          'ndb_index_stat_cache_entries',
+          'ndb_index_stat_enable',
+          'ndb_index_stat_option',
+          'ndb_index_stat_update_freq',
+          'ndb_log_apply_status',
+          'ndb_log_empty_epochs',
+          'ndb_log_empty_update',
+          'ndb_log_exclusive_reads',
+          'ndb_log_orig',
+          'ndb-log-update-minimal',
+          'ndb_log_updated_only',
+          'ndb_optimized_node_selection',
+          'ndb_read_backup',
+          'ndb_report_thresh_binlog_epoch_slip',
+          'ndb_report_thresh_binlog_mem_usage',
+          'ndb_show_foreign_key_mock_tables',
+          'ndb_slave_conflict_role',
+          'ndb_use_transactions',
+          'ndbcluster']),
       ( 'Memcached',
         [ 'daemon_memcached_enable_binlog',
           'daemon_memcached_engine_lib_name',
           'daemon_memcached_engine_lib_path',
           'daemon_memcached_option',
           'daemon_memcached_r_batch_size',
-          'daemon_memcached_w_batch_size'])]),
+          'daemon_memcached_w_batch_size']),
+      ( 'Storage Engines',
+        ['skip-bdb', 'skip-falcon', 'skip-merge', 'skip-sync-bdb-logs'])]),
   ( 'Security',
-    [ ( 'Security',
+    [ ( 'Authentication',
+        [ 'activate_all_roles_on_login',
+          'check_proxy_users',
+          'connection_control_failed_connections_threshold',
+          'connection_control_max_connection_delay',
+          'connection_control_min_connection_delay',
+          'default_authentication_plugin',
+          'default_password_lifetime',
+          'disconnect_on_expired_password',
+          'keyring_aws_cmk_id',
+          'keyring_aws_conf_file',
+          'keyring_aws_data_file',
+          'keyring_aws_region',
+          'keyring_encrypted_file_data',
+          'keyring_encrypted_file_password',
+          'keyring_file_data',
+          'keyring-migration-destination',
+          'keyring-migration-host',
+          'keyring-migration-password',
+          'keyring-migration-port',
+          'keyring-migration-socket',
+          'keyring-migration-source',
+          'keyring-migration-user',
+          'keyring_okv_conf_dir',
+          'authentication_ldap_sasl_auth_method_name',
+          'authentication_ldap_sasl_bind_base_dn',
+          'authentication_ldap_sasl_bind_root_dn',
+          'authentication_ldap_sasl_bind_root_pwd',
+          'authentication_ldap_sasl_ca_path',
+          'authentication_ldap_sasl_group_search_attr',
+          'authentication_ldap_sasl_group_search_filter',
+          'authentication_ldap_sasl_init_pool_size',
+          'authentication_ldap_sasl_log_status',
+          'authentication_ldap_sasl_max_pool_size',
+          'authentication_ldap_sasl_server_host',
+          'authentication_ldap_sasl_server_port',
+          'authentication_ldap_sasl_tls',
+          'authentication_ldap_sasl_user_search_attr',
+          'authentication_ldap_simple_auth_method_name',
+          'authentication_ldap_simple_bind_base_dn',
+          'authentication_ldap_simple_bind_root_dn',
+          'authentication_ldap_simple_bind_root_pwd',
+          'authentication_ldap_simple_ca_path',
+          'authentication_ldap_simple_group_search_attr',
+          'authentication_ldap_simple_group_search_filter',
+          'authentication_ldap_simple_init_pool_size',
+          'authentication_ldap_simple_log_status',
+          'authentication_ldap_simple_max_pool_size',
+          'authentication_ldap_simple_server_host',
+          'authentication_ldap_simple_server_port',
+          'authentication_ldap_simple_tls',
+          'authentication_ldap_simple_user_search_attr',
+          'mysql_native_password_proxy_users',
+          'password_history',
+          'password_reuse_interval',
+          'sha256_password_auto_generate_rsa_keys',
+          'sha256_password_private_key_path',
+          'sha256_password_proxy_users',
+          'sha256_password_public_key_path',
+          'tls_version',
+          'validate-password',
+          'validate_password.check_user_name',
+          'validate_password_check_user_name']),
+      ( 'Security',
         [ 'allow-suspicious-udfs',
           'authentication_windows_log_level',
           'authentication_windows_use_principal_name',
+          'auto_generate_certs',
+          'block_encryption_mode',
+          'caching_sha2_password_auto_generate_rsa_keys',
+          'caching_sha2_password_private_key_path',
+          'caching_sha2_password_public_key_path',
           'des-key-file',
           'read_only',
+          'require_secure_transport',
           'safe-mode',
           'safe-show-database',
           'safe-user-create',
           'safemalloc-mem-limit',
+          'schema_definition_cache',
           'secure-auth',
           'secure-backup-file-priv',
           'secure-file-priv',
           'skip-grant-tables',
-          'skip-show-database',
-          'block_encryption_mode']),
-      ( 'Validate password',
-        [ 'validate-password',
-          'validate_password_dictionary_file',
-          'validate_password_length',
-          'validate_password_mixed_case_count',
-          'validate_password_number_count',
-          'validate_password_policy_number',
-          'validate_password_special_char_count']),
-      ( 'Authentication',
-        [ 'default-authentication-plugin',
-          'old_passwords',
-          'default_authentication_plugin',
-          'default_password_lifetime',
-          'disconnect_on_expired_password'])]),
+          'skip-show-database'])]),
   ( 'Replication',
     [ ( 'Relay Log',
         [ 'max_relay_log_size',
           'relay-log',
-          'relay-log-index',
-          'relay-log-info-file',
-          'relay_log_info_file',
           'relay-log-info-repository',
           'relay_log_index',
+          'relay_log_info_file',
           'relay_log_purge',
-          'relay-log-recovery',
           'relay_log_recovery',
           'relay_log_space_limit',
           'sync_relay_log',
           'sync_relay_log_info']),
+      ( 'Slave',
+        [ 'abort-slave-event-count',
+          'disconnect-slave-event-count',
+          'init_slave',
+          'rpl_stop_slave_timeout',
+          'show-slave-auth-info',
+          'slave-load-tmpdir',
+          'slave-max-allowed-packet',
+          'slave-net-timeout',
+          'slave-parallel-type',
+          'slave-parallel-workers',
+          'slave-rows-search-algorithms',
+          'slave-skip-errors',
+          'slave-sql-verify-checksum',
+          'slave_allow_batching',
+          'slave_checkpoint_group',
+          'slave_checkpoint_period',
+          'slave_compressed_protocol',
+          'slave_exec_mode',
+          'slave_transaction_retries',
+          'slave_type_conversions']),
       ( 'Master',
-        [ 'auto_increment_increment',
-          'auto_increment_offset',
-          'master-connect-retry',
+        [ 'master-connect-retry',
           'master-host',
           'master-info-file',
-          'master-info-repository',
           'master-password',
           'master-port',
           'master-retry-count',
@@ -505,34 +720,58 @@ layout = [ ( 'General',
           'master-ssl-key',
           'master-user',
           'master-verify-checksum',
-          'sync_master_info',
-          'master_info_repository']),
-      ( 'Slave',
-        [ 'slave_exec_mode',
-          'abort-slave-event-count',
-          'disconnect-slave-event-count',
-          'init_slave',
-          'show-slave-auth-info',
-          'slave_allow_batching',
-          'slave-load-tmpdir',
-          'slave-skip-errors',
-          'slave-checkpoint-group',
-          'slave_checkpoint_group',
-          'slave-checkpoint-period',
-          'slave_checkpoint_period',
-          'slave_compressed_protocol',
-          'slave-max-allowed-packet',
-          'slave-net-timeout',
-          'slave-parallel-workers',
-          'slave-rows-search-algorithms',
-          'slave-sql-verify-checksum',
-          'slave_transaction_retries',
-          'slave_type_conversions',
-          'rpl_stop_slave_timeout',
-          'slave-parallel-type']),
+          'master_info_repository',
+          'sync_master_info']),
+      ( 'Group',
+        [ 'group_replication_group_name',
+          'group_replication_start_on_boot',
+          'group_replication_local_address',
+          'group_replication_member_weight',
+          'group_replication_group_seeds',
+          'group_replication_force_members',
+          'group_replication_bootstrap_group',
+          'group_replication_poll_spin_loops',
+          'group_replication_recovery_get_public_key',
+          'group_replication_recovery_public_key_path',
+          'group_replication_recovery_retry_count',
+          'group_replication_recovery_reconnect_interval',
+          'group_replication_recovery_use_ssl',
+          'group_replication_recovery_ssl_ca',
+          'group_replication_recovery_ssl_capath',
+          'group_replication_recovery_ssl_cert',
+          'group_replication_recovery_ssl_key',
+          'group_replication_recovery_ssl_cipher',
+          'group_replication_recovery_ssl_crl',
+          'group_replication_recovery_ssl_crlpath',
+          'group_replication_recovery_ssl_verify_server_cert',
+          'group_replication_recovery_complete_at',
+          'group_replication_communication_debug_options',
+          'group_replication_components_stop_timeout',
+          'group_replication_allow_local_lower_version_join',
+          'group_replication_allow_local_disjoint_gtids_join',
+          'group_replication_auto_increment_increment',
+          'group_replication_compression_threshold',
+          'group_replication_gtid_assignment_block_size',
+          'group_replication_ssl_mode',
+          'group_replication_single_primary_mode',
+          'group_replication_transaction_size_limit',
+          'group_replication_unreachable_majority_timeout',
+          'group_replication_enforce_update_everywhere_checks',
+          'group_replication_flow_control_mode',
+          'group_replication_flow_control_certifier_threshold',
+          'group_replication_flow_control_applier_threshold',
+          'group_replication_flow_control_hold_percent',
+          'group_replication_flow_control_max_commit_quota',
+          'group_replication_flow_control_member_quota_percent',
+          'group_replication_flow_control_min_quota',
+          'group_replication_flow_control_min_recovery_quota',
+          'group_replication_flow_control_period',
+          'group_replication_flow_control_release_percent',
+          'group_replication_ip_whitelist']),
       ( 'General',
-        [ 'disable-gtid-unsafe-statements',
-          'disable_gtid_unsafe_statements',
+        [ 'disable_gtid_unsafe_statements',
+          'enforce_gtid_consistency',
+          'executed-gtids-compression-period',
           'gtid-mode',
           'init-rpl-role',
           'replicate-do-db',
@@ -547,18 +786,17 @@ layout = [ ( 'General',
           'report-password',
           'report-port',
           'report-user',
-          'skip-slave-start',
-          'enforce_gtid_consistency',
-          'executed-gtids-compression-period'])]),
+          'rpl_read_size',
+          'skip-slave-start'])]),
   ( 'MyISAM',
     [ ( 'Advanced Settings',
         [ 'myisam-block-size',
+          'myisam-recover',
+          'myisam-recover-options',
           'myisam_data_pointer_size',
           'myisam_max_extra_sort_file_size',
           'myisam_max_sort_file_size',
           'myisam_mmap_size',
-          'myisam-recover',
-          'myisam-recover-options',
           'myisam_repair_threads',
           'myisam_sort_buffer_size',
           'myisam_stats_method',
@@ -583,43 +821,14 @@ layout = [ ( 'General',
           'query_cache_wlock_invalidate']),
       ( 'Optimizer',
         [ 'engine-condition-pushdown',
+          'histogram_generation_max_mem_size',
+          'information_schema_stats_expiry',
           'optimizer_join_cache_level',
           'optimizer_prune_level',
           'optimizer_search_depth',
           'optimizer_switch']),
       ( 'Performance Schema',
-        [ 'performance_schema',
-          'performance_schema_consumer_xxx',
-          'performance_schema_digests_size',
-          'performance_schema_events_stages_history_long_size',
-          'performance_schema_events_stages_history_size',
-          'performance_schema_events_statements_history_long_size',
-          'performance_schema_events_statements_history_size',
-          'performance_schema_events_waits_history_long_size',
-          'performance_schema_events_waits_history_size',
-          'performance_schema_hosts_size',
-          'performance_schema_instrument',
-          'performance_schema_max_cond_classes',
-          'performance_schema_max_cond_instances',
-          'performance_schema_max_file_classes',
-          'performance_schema_max_file_handles',
-          'performance_schema_max_file_instances',
-          'performance_schema_max_mutex_classes',
-          'performance_schema_max_mutex_instances',
-          'performance_schema_max_rwlock_classes',
-          'performance_schema_max_rwlock_instances',
-          'performance_schema_max_stage_classes',
-          'performance_schema_max_socket_classes',
-          'performance_schema_max_socket_instances',
-          'performance_schema_max_statement_classes',
-          'performance_schema_max_table_handles',
-          'performance_schema_max_table_instances',
-          'performance_schema_max_thread_classes',
-          'performance_schema_max_thread_instances',
-          'performance_schema_setup_actors_size',
-          'performance_schema_setup_objects_size',
-          'performance_schema_users_size',
-          'performance-schema-consumer-events-stages-current',
+        [ 'performance-schema-consumer-events-stages-current',
           'performance-schema-consumer-events-stages-history',
           'performance-schema-consumer-events-stages-history-long',
           'performance-schema-consumer-events-statements-current',
@@ -635,19 +844,51 @@ layout = [ ( 'General',
           'performance-schema-consumer-statements-digest',
           'performance-schema-consumer-thread-instrumentation',
           'performance-schema-instrument',
+          'performance_schema',
           'performance_schema_accounts_size',
+          'performance_schema_digests_size',
+          'performance_schema_error_size',
+          'performance_schema_events_stages_history_long_size',
+          'performance_schema_events_stages_history_size',
+          'performance_schema_events_statements_history_long_size',
+          'performance_schema_events_statements_history_size',
           'performance_schema_events_transactions_history_long_size',
           'performance_schema_events_transactions_history_size',
+          'performance_schema_events_waits_history_long_size',
+          'performance_schema_events_waits_history_size',
+          'performance_schema_hosts_size',
+          'performance_schema_max_cond_classes',
+          'performance_schema_max_cond_instances',
+          'performance_schema_max_digest_length',
+          'performance_schema_max_digest_sample_age',
+          'performance_schema_max_file_classes',
+          'performance_schema_max_file_handles',
+          'performance_schema_max_file_instances',
+          'performance_schema_max_index_stat',
           'performance_schema_max_memory_classes',
           'performance_schema_max_metadata_locks',
+          'performance_schema_max_mutex_classes',
+          'performance_schema_max_mutex_instances',
           'performance_schema_max_prepared_statements_instances',
           'performance_schema_max_program_instances',
+          'performance_schema_max_rwlock_classes',
+          'performance_schema_max_rwlock_instances',
+          'performance_schema_max_socket_classes',
+          'performance_schema_max_socket_instances',
+          'performance_schema_max_sql_text_length',
+          'performance_schema_max_stage_classes',
+          'performance_schema_max_statement_classes',
           'performance_schema_max_statement_stack',
-          'performance_schema_session_connect_attrs_size']),
+          'performance_schema_max_table_handles',
+          'performance_schema_max_table_instances',
+          'performance_schema_max_table_lock_stat',
+          'performance_schema_max_thread_classes',
+          'performance_schema_max_thread_instances',
+          'performance_schema_session_connect_attrs_size',
+          'performance_schema_setup_actors_size',
+          'performance_schema_setup_objects_size',
+          'performance_schema_users_size']),
       ( 'General',
         [ 'delay-key-write',
           'low-priority-updates',
-          'profiling_history_size',
-          'table_definition_cache',
-          'table_open_cache',
-          'table_open_cache_instances'])])]
+          'profiling_history_size'])])]
