@@ -1,21 +1,26 @@
-# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is designed to work with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have either included with
+# the program or referenced in the documentation.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+
 
-from __future__ import with_statement
 
 # import the wb module
 from wb import DefineModule, wbinputs
@@ -62,7 +67,10 @@ def initialize0():
     nc.add_observer(sqlide_power_import_wizard.handleContextMenu, name = "GRNLiveDBObjectMenuWillShow")
     nc.add_observer(sqlide_power_export_wizard.handleContextMenu, name = "GRNLiveDBObjectMenuWillShow")
 
-
+@ModuleInfo.export(grt.INT, grt.classes.db_query_Editor)
+def launchPowerImport(editor):
+    sqlide_power_import_wizard.showPowerImport(editor, {'table': None, 'schema': editor.defaultSchema})
+    return 0
 
 @ModuleInfo.export(grt.INT, grt.classes.db_query_EditableResultset)
 def importRecordsetDataFromFile(resultset):
@@ -71,7 +79,7 @@ def importRecordsetDataFromFile(resultset):
     file_chooser.set_directory(os.path.expanduser('~'))
     file_chooser.set_extensions('CSV Files (*.csv)|*.csv', 'import')
     if file_chooser.run_modal():
-        with open(file_chooser.get_path(), 'rb') as import_file:
+        with open(file_chooser.get_path(), 'r') as import_file:
             ext = os.path.splitext(import_file.name)[1].lower()
             import_module = None
             if ext == '.csv':
@@ -114,7 +122,7 @@ def importRecordsetDataFromFile(resultset):
     return 0
 
 
-@ModuleInfo.plugin("wb.sqlide.executeToTextOutput", caption= "Execute Query Into Text Output", input= [wbinputs.currentQueryEditor()])
+@ModuleInfo.plugin("wb.sqlide.executeToTextOutput", caption= "Execute Query Into Text Output", input= [wbinputs.currentQueryEditor()], accessibilityName="Execute Into Text Output")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryEditor)
 def executeQueryAsText(qbuffer):
   
@@ -185,7 +193,7 @@ def executeQueryAsText(qbuffer):
     return 0
 
 
-@ModuleInfo.plugin('wb.sqlide.verticalOutput', caption='Vertical Output', input=[wbinputs.currentQueryEditor()])
+@ModuleInfo.plugin('wb.sqlide.verticalOutput', caption='Vertical Output', input=[wbinputs.currentQueryEditor()], accessibilityName="Execute Into Vertical Output")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryEditor)
 def verticalOutput(editor):
     statement = editor.currentStatement
@@ -212,15 +220,14 @@ def verticalOutput(editor):
         dock = mforms.fromgrt(editor.resultDockingPoint)
         dock.dock_view(view, '', 0)
         dock.select_view(view)
-        dock.set_view_title(view, 'Vertical Output')
+        view.set_title('Vertical Output')
 
 
     return 0
 
 
 def doReformatSQLStatement(text, return_none_if_unsupported):
-    from grt.modules import MysqlSqlFacade
-    ast_list = MysqlSqlFacade.parseAstFromSqlScript(text)
+    ast_list = grt.modules.MysqlSqlFacade.parseAstFromSqlScript(text)
     if len(ast_list) != 1:
         raise Exception("Error parsing statement")
     if type(ast_list[0]) is str:
@@ -263,13 +270,11 @@ def reformatSQLStatement(text):
     return doReformatSQLStatement(text, False)
 
 
-@ModuleInfo.plugin("wb.sqlide.enbeautificate", caption = "Reformat SQL Query", input=[wbinputs.currentQueryBuffer()])
+@ModuleInfo.plugin("wb.sqlide.enbeautificate", caption = "Reformat SQL Query", input=[wbinputs.currentQueryBuffer()], accessibilityName="Reformat Query")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryBuffer)
 def enbeautificate(editor):
     """Reformat the selected SQL statements or the one under the cursor."""
 
-    from grt.modules import MysqlSqlFacade
-
     text = editor.selectedText
     selectionOnly = True
     if not text:
@@ -281,7 +286,7 @@ def enbeautificate(editor):
     
     prev_end = 0
     new_text = []
-    ranges = MysqlSqlFacade.getSqlStatementRanges(text)
+    ranges = grt.modules.MysqlSqlFacade.getSqlStatementRanges(text)
     for begin, end in ranges:
         end = begin + end
         if begin > prev_end:
@@ -358,7 +363,6 @@ def enbeautificate(editor):
 
 
 def apply_to_keywords(editor, callable):
-    from grt.modules import MysqlSqlFacade
     non_keywords = ["ident", "ident_or_text", "TEXT_STRING", "text_string", "TEXT_STRING_filesystem", "TEXT_STRING_literal", "TEXT_STRING_sys",
                     "part_name"]
 
@@ -369,12 +373,12 @@ def apply_to_keywords(editor, callable):
         text = editor.script
     
     new_text = ""
-    ast_list = MysqlSqlFacade.parseAstFromSqlScript(text)
+    ast_list = grt.modules.MysqlSqlFacade.parseAstFromSqlScript(text)
     bb = 0
     for ast in ast_list:
         if type(ast) is str:
             # error
-            print ast
+            print(ast)
             mforms.App.get().set_status_text("Cannot format invalid SQL: %s"%ast)
             return 1
         else:
@@ -409,13 +413,13 @@ def apply_to_keywords(editor, callable):
     return 0
 
 
-@ModuleInfo.plugin("wb.sqlide.upcaseKeywords", caption = "Make keywords in query uppercase", input=[wbinputs.currentQueryEditor()])
+@ModuleInfo.plugin("wb.sqlide.upcaseKeywords", caption = "Make keywords in query uppercase", input=[wbinputs.currentQueryEditor()], accessibilityName="Uppercase Query Keywords")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryEditor)
 def upcaseKeywords(editor):
     return apply_to_keywords(editor, lambda s: s.upper())
 
 
-@ModuleInfo.plugin("wb.sqlide.lowercaseKeywords", caption = "Make keywords in query lowercase", input=[wbinputs.currentQueryEditor()])
+@ModuleInfo.plugin("wb.sqlide.lowercaseKeywords", caption = "Make keywords in query lowercase", input=[wbinputs.currentQueryEditor()], accessibilityName="Lowercase Query Keywords")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryEditor)
 def lowercaseKeywords(editor):
     return apply_to_keywords(editor, lambda s: s.lower())
@@ -457,7 +461,7 @@ def get_lines_in_range(text, range_start, range_end):
     return (first_line_start, last_line_end, lines)
 
 
-@ModuleInfo.plugin("wb.sqlide.indent", caption = "Indent Selected Lines", input=[wbinputs.currentQueryEditor()])
+@ModuleInfo.plugin("wb.sqlide.indent", caption = "Indent Selected Lines", input=[wbinputs.currentQueryEditor()], accessibilityName="Indent Selected Lines")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryEditor)
 def indent(editor):
     # indent and unindent handle selection a bit differently:
@@ -493,7 +497,7 @@ def indent(editor):
 
 
 
-@ModuleInfo.plugin("wb.sqlide.unindent", caption = "Unindent Selected Lines", input=[wbinputs.currentQueryEditor()])
+@ModuleInfo.plugin("wb.sqlide.unindent", caption = "Unindent Selected Lines", input=[wbinputs.currentQueryEditor()], accessibilityName="Unindent Selected Lines")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryEditor)
 def unindent(editor):
     indentation = " "*4
@@ -547,7 +551,7 @@ def unindent(editor):
     return 0
 
 
-@ModuleInfo.plugin("wb.sqlide.comment", caption = "Un/Comment Selection", input=[wbinputs.currentQueryEditor()])
+@ModuleInfo.plugin("wb.sqlide.comment", caption = "Un/Comment Selection", input=[wbinputs.currentQueryEditor()], accessibilityName="Comment or Uncomment Selection")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_QueryEditor)
 def commentText(editor):
     commentType = "%s " % grt.root.wb.options.options["DbSqlEditor:SQLCommentTypeForHotkey"]
@@ -558,7 +562,7 @@ def commentText(editor):
         if lines[0].startswith(commentType):
             new_text = "\n".join((line[commentTypeLength:] if line.startswith(commentType) else line) for line in lines)
         else:
-            new_text = "\n".join(commentType + line for line in lines)
+            new_text = "\n".join(commentType + line if line != "" else line for line in lines)
         editor.replaceSelection(new_text)
     else:
         pos = editor.insertionPoint
@@ -615,7 +619,7 @@ def showInspector(editor, selection):
 #    pass
 
 
-@ModuleInfo.plugin("wb.sqlide.runScript", caption = "Run SQL Script", input=[wbinputs.currentSQLEditor()])
+@ModuleInfo.plugin("wb.sqlide.runScript", caption = "Run SQL Script", input=[wbinputs.currentSQLEditor()], accessibilityName="Run SQL Script")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor)
 def runSQLScript(editor):
     form = RunScriptForm(editor)
